# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

Name:           javacc
Version:        5.0
Release:        %mkrel 15
Group:          Development/Java
Epoch:          0
Summary:        A parser/scanner generator for java
License:        BSD
Source0:        http://java.net/projects/%{name}/downloads/download/%{name}-%{version}src.tar.gz
Source1:        javacc.sh
Source2:        jjdoc
Source3:        jjtree
Patch0:         0001-Add-javadoc-target-to-build.xml.patch
URL:            http://javacc.java.net/
Requires:       java-headless
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  junit
BuildRequires:  javacc
BuildRequires:  java-devel

BuildArch:      noarch

%description 
Java Compiler Compiler (JavaCC) is the most popular parser generator for use
with Java applications. A parser generator is a tool that reads a grammar
specification and converts it to a Java program that can recognize matches to
the grammar. In addition to the parser generator itself, JavaCC provides other
standard capabilities related to parser generation such as tree building (via
a tool called JJTree included with JavaCC), actions, debugging, etc.

%package manual
Summary:        Manual for %{name}

%description manual
Manual for %{name}.

%package demo
Summary:        Examples for %{name}
Requires:       %{name} = %{version}-%{release}

%description demo
Examples for %{name}.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n %{name}

%patch0 -p1

# Remove binary information in the source tar
find . -name "*.jar" -delete
find . -name "*.class" -delete

find ./examples -type f -exec sed -i 's/\r//' {} \;

ln -s `build-classpath javacc` bootstrap/javacc.jar

sed -i 's/source="1.4"/source="1.5"/g' src/org/javacc/{parser,jjdoc,jjtree}/build.xml

%build
# Use the bootstrap javacc.jar to generate some required
# source java files. After these source files are generated we
# remove the bootstrap jar and build the binary from source.
ant -f src/org/javacc/parser/build.xml parser-files
ant -f src/org/javacc/jjtree/build.xml tree-files
find . -name "*.jar" -delete
ant jar javadoc

%install
# jar
install -Dpm 644 bin/lib/%{name}.jar %{buildroot}%{_javadir}/%{name}.jar

# bin
install -Dp -T -m 755 %{SOURCE1} %{buildroot}/%{_bindir}/javacc.sh
install -Dp -T -m 755 %{SOURCE2} %{buildroot}/%{_bindir}/jjdoc
install -Dp -T -m 755 %{SOURCE3} %{buildroot}/%{_bindir}/jjtree

# javadoc
install -d -p 755 %{buildroot}/%{_javadocdir}/%{name}
cp -rp api/* %{buildroot}/%{_javadocdir}/%{name}

# pom
install -Dpm 644 pom.xml %{buildroot}/%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap JPP-%{name}.pom %{name}.jar


%files -f .mfiles
%{_javadir}/*.jar
%doc LICENSE README
%{_bindir}/*

%files manual
%doc LICENSE README
%doc www/*

%files demo
%doc examples

%files javadoc
%doc LICENSE README
%{_javadocdir}/%{name}



%changelog
* Wed Mar 02 2016 neoclust <neoclust> 0:5.0-15.mga6
+ Revision: 982182
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 0:5.0-14.mga6
+ Revision: 976515
- First rebuild of the java stack
- sync package javacc with fedora

* Thu Feb 18 2016 umeabot <umeabot> 0:5.0-8.mga6
+ Revision: 965538
- Mageia 6 Mass Rebuild

* Wed Jan 21 2015 daviddavid <daviddavid> 0:5.0-7.mga5
+ Revision: 811818
- Sync with fc21

* Wed Oct 15 2014 umeabot <umeabot> 0:5.0-6.mga5
+ Revision: 739928
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:5.0-5.mga5
+ Revision: 680648
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0:5.0-4.mga4
+ Revision: 506207
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 0:5.0-3.mga3
+ Revision: 354819
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 dmorgan <dmorgan> 0:5.0-2.mga3
+ Revision: 325657
- Fixing #835786 - javacc: Invalid upstream URL
- Minor spec file changes according to the latest guidelines

* Mon Jan 17 2011 dmorgan <dmorgan> 5.0-1.mga1
+ Revision: 21386
- Add _mavenpomdir
- New version 5.0
  Sync with fedora

* Mon Jan 17 2011 dmorgan <dmorgan> 4.1-0.5.mga1
+ Revision: 21336
- imported package javacc


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 4.1-0.5mdv2011.0
+ Revision: 606070
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 4.1-0.4mdv2010.1
+ Revision: 523038
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 4.1-0.3mdv2010.0
+ Revision: 425452
- rebuild

* Wed Feb 18 2009 Jérôme Soyer <saispo@mandriva.org> 4.1-0.2mdv2009.1
+ Revision: 342286
- Remove unneeded BR
- Add BR
- fix typo for gcj
- Fix type
- Clean spec
- spec cleanup
- New upstream release

* Thu Feb 14 2008 Thierry Vignaud <tv@mandriva.org> 0:4.0-3.6mdv2009.0
+ Revision: 167964
- fix no-buildroot-tag
- kill re-definition of %%buildroot on Pixel's request

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 0:4.0-3.6mdv2008.1
+ Revision: 120925
- buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:4.0-3.5mdv2008.0
+ Revision: 87424
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Sun Sep 09 2007 Pascal Terjan <pterjan@mandriva.org> 0:4.0-3.4mdv2008.0
+ Revision: 83399
- bzip2 the source as rpm fails on .tar
- Don't name .bz2 a simple tar


* Sat Dec 16 2006 David Walluck <walluck@mandriva.org> 4.0-3.4mdv2007.0
+ Revision: 98056
- enable bootstrap
- bunzip2 patch
- rebuild
- Import javacc

* Sun Jul 23 2006 David Walluck <walluck@mandriva.org> 0:4.0-3.1mdv2007.0
- bump release

* Mon Jun 05 2006 David Walluck <walluck@mandriva.org> 0:4.0-2.2mdv2007.0
- BuildRequires: java-gcj-compat-devel
- use %%{update_gcjdb} and %%{clean_gcjdb}

* Thu May 25 2006 David Walluck <walluck@mandriva.org> 0:4.0-2.1mdv2007.0
- rebuild for libgcj.so.7
- update release for JPackage 1.7

* Thu Mar 02 2006 David Walluck <walluck@mandriva.org> 0:4.0-1mdk
* Fri Nov 11 2005 David Walluck <walluck@mandriva.org> 0:3.2-2.2mdk
- aot compile

* Sat May 28 2005 David Walluck <walluck@mandriva.org> 0:3.2-2.1mdk
- release

* Tue Aug 24 2004 Randy Watler <rwatler at finali.com> - 0:3.2-2jpp
- Rebuild with ant-1.6.2

* Fri Jan 30 2004 Sebastiano Vigna <vigna@acm.org> 0:3.2-1jpp
- First JPackage version

